/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.kvisco.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id: StringFunctionCall.java 4093 2004-01-26 23:46:06Z kvisco $
 */


package org.exolab.adaptx.xpath.functions;


import org.exolab.adaptx.xpath.XPathNode;
import org.exolab.adaptx.xpath.XPathResult;
import org.exolab.adaptx.xpath.XPathContext;
import org.exolab.adaptx.xpath.StringResult;
import org.exolab.adaptx.xpath.XPathException;
import org.exolab.adaptx.xpath.engine.Names;


/**
 * A implementation of the "string()" function call
 *
 * @author <a href="mailto:kvisco@intalio.com">Keith Visco</a>
 * @version $Revision: 4093 $
 */
public class StringFunctionCall
    extends FunctionCallImpl
{

    /**
     * Creates a new String FunctionCall
    **/
    public StringFunctionCall()
    {
        super( Names.STRING_FN );
    } //-- StringFunctionCall
    

    /**
     * Evaluates the expression and returns the XPath result.
     *
     * @param context The XPathContext to use during evaluation.
     * @return The XPathResult (not null).
     * @exception XPathException if an error occured while 
     * evaluating this expression.
    **/
    public XPathResult evaluate( XPathContext context )
        throws XPathException
    {
        int nparams = getParameterCount();
        if ( nparams > 1 )
            throw new XPathException( INVALID_NUMBER_PARAMS + this );
        if ( nparams == 1 ) {
            XPathResult result = getParameter( 0 ).evaluate( context );
            String value = result.stringValue();
            if (value == null) value = ""; //-- prevent NPE in StringResult
            return new StringResult( value );
        }
        XPathNode node = context.getNode();
        return new StringResult( node.getStringValue() );
    } //-- evaluate

    
} //-- StringFunction

