/*
 * (C) Copyright Keith Visco 2001  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id: Root.java 3914 2003-09-29 19:30:53Z kvisco $
 */


package org.exolab.adaptx.xslt.dom;

import org.exolab.adaptx.xpath.XPathNode;

/**
 * A representation of a Root node
 *
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision: 3914 $ $Date: 2003-09-29 15:30:53 -0400 (Mon, 29 Sep 2003) $
 */
public class Root extends ParentNode {

    private static final String ROOT_NAME = "#root";
    
    private String _uri = null;
    
    /**
     * Creates a new Root Node
     *
    **/
    public Root() {
        super(null, ROOT_NAME);
    } //-- Root
    
    /**
     * Returns the URI for this root node, or null if unknown.
     *
     * @return the URI for this root node, or null if unknown.
     */
    public String getDocumentURI() {
        return _uri;
    } //-- getDocumentURI

    /**
     * Returns the type of this node.
     *
     * @return The type of this node
    **/
    public int getNodeType() {
        return XPathNode.ROOT;
    } //-- getNodeType
    
    /**
     * Returns the root node.
     *
     * @return The root node
    **/
    public XPathNode getRootNode() {
        return this;
    } //-- getRootNode
    
    /**
     * Sets the DocumentURI for this root node
     *
     * @param uri the document URI 
     */
    protected void setDocumentURI(String uri) {
        _uri = uri;
    } //-- setDocumentURI

} //-- Root
